@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.080'; 
+our $VERSION = '1.081'; 
 $VERSION = eval $VERSION;
 
 use strict;
@@ -89,6 +89,8 @@ use constant API_MARK_READ	     => 19;
 use constant API_MARKALL	     => 20;
 use constant API_MY_SUBREDDITS       => 21;
 use constant API_USER                => 22;
+use constant API_SELECTFLAIR         => 23;
+use constant API_FLAIROPTS           => 24;
 
 #===============================================================================
 # Parameters
@@ -125,6 +127,8 @@ $API[API_MESSAGES      ] = ['GET',  '/message/%s'           ];
 $API[API_MARK_READ     ] = ['POST', '/api/read_message'     ];
 $API[API_MARKALL       ] = ['POST', '/api/read_all_messages'];
 $API[API_USER          ] = ['GET',  '/user/%s/%s'           ];
+$API[API_SELECTFLAIR   ] = ['POST', '/r/%s/api/selectflair' ];
+$API[API_FLAIROPTS     ] = ['POST', '/r/%s/api/flairselector'];
 #===============================================================================
 # Package routines
 #===============================================================================
@@ -220,6 +224,9 @@ sub request {
     $path =~ s/^\/+//;
     my $request = Reddit::Client::Request->new(
         user_agent => $self->{user_agent},
+		   # path is sprintf'd before call, in api_json_request
+		   # the calling function passes in path %s's in 'args' param, 
+		   # an array REFERENCE
         url        => sprintf('%s/%s', $BASE_URL, $path),
         method     => $method,
         query      => $query,
@@ -364,8 +371,10 @@ sub list_subreddits {
         $query->{after}  = $param{after}  if $param{after};
 	if (exists $param{limit}) { $query->{limit} = $param{limit} || 500; }
 	else 			  { $query->{limit} = DEFAULT_LIMIT;	    }
-    DEBUG('List subreddits [%s]', $type);
-    defined $type || croak 'Expected $type"';
+
+	DEBUG('List subreddits [%s]', $type);
+	defined $type || croak 'Expected $type"';
+
 	my $api = $type eq SUBREDDITS_MOD || $type eq SUBREDDITS_CONTRIB || $type eq SUBREDDITS_MINE ? API_MY_SUBREDDITS : API_SUBREDDITS; 
 
     my $result = $self->api_json_request(
@@ -689,6 +698,83 @@ sub submit_text {
 
     return $result->{data}{name};
 }
+# This could go in the user section or here, but it seems like it will be
+# more commonly used for flairing posts
+sub set_post_flair {
+    	my ($self, %param) = @_;
+	my $sub 	= $param{subreddit} || croak "Expected 'subreddit'";
+	my $post_id 	= $param{post_id} || croak "Need 'post_id'";
+	my $flairid	= $param{flair_template_id} || croak "need 'flair template id'";
+	my $data	= {};
+
+	if (!$self->ispost($post_id)) { $post_id = "t3_".$post_id; }
+	$data->{link} = $post_id;
+	$data->{flair_template_id} = $flairid;
+
+	my $result = $self->api_json_request(
+		api 	=> API_SELECTFLAIR,
+		args 	=> [$sub],
+		data	=> $data
+	);
+
+	#return @{$result->{data}{children}};
+}
+sub set_user_flair {
+    	my ($self, %param) = @_;
+	my $sub 	= $param{subreddit} || croak "Expected 'subreddit'";
+	my $user 	= $param{username} || croak "Need 'username'";
+	my $flairid	= $param{flair_template_id} || croak "need 'flair template id'";
+	my $data	= {};
+
+	$data->{name} = $user;
+	$data->{flair_template_id} = $flairid;
+
+	my $result = $self->api_json_request(
+		api 	=> API_SELECTFLAIR,
+		args 	=> [$sub],
+		data	=> $data
+	);
+
+	#return @{$result->{data}{children}};
+}
+
+# Return a hash reference with keys 'choices' and 'current'
+# 'choices' is array of hashes with flair options
+# 'current' is the post's current flair
+sub get_flair_options {
+    	my ($self, %param) = @_;
+	my $sub 	= $param{subreddit} || croak "Expected 'subreddit'";
+	my $post_id 	= $param{post_id};
+	my $user	= $param{username};
+	my $data	= {};
+
+	# what happens when both are sent?
+	if ($post_id) {
+		if (!$self->ispost($post_id)) { $post_id = "t3_".$post_id; }
+		$data->{link} = $post_id;
+	} elsif ($user) {
+		$data->{user} = $user;
+	} else {
+		croak "Need 'post_id' or 'username'";
+	}
+
+
+	my $result = $self->api_json_request(
+		api 	=> API_FLAIROPTS,
+		args 	=> [$sub],
+		data	=> $data,
+	);
+
+	if ($result->{choices}) {
+		for (my $i=0; $result->{choices}[$i]; $i++) {
+			$result->{choices}[$i]->{flair_text_editable} = $result->{choices}[$i]->{flair_text_editable} ? 1 : 0;
+
+		}
+	}
+
+
+	return $result;
+}
 
 #===============================================================================
 # Comments
