@@ -31,7 +31,7 @@ sub replies {
 sub reply {
     my ($self, $text) = @_;
 	$text || croak "need comment text";	
-	my $cmtid = $self->{session}->submit_comment(parent_id=>$self->{parent_id}, text=>$text);
+	my $cmtid = $self->{session}->submit_comment(parent_id=>$self->{name}, text=>$text);
 	return "t1_".$cmtid if $cmtid;
 	return $cmtid;
     #return $self->SUPER::submit_comment(@_);
